aboutsummaryrefslogtreecommitdiffstats
path: root/swarm/storage/localstore/localstore_test.go
diff options
context:
space:
mode:
Diffstat (limited to 'swarm/storage/localstore/localstore_test.go')
-rw-r--r--swarm/storage/localstore/localstore_test.go10
1 files changed, 5 insertions, 5 deletions
diff --git a/swarm/storage/localstore/localstore_test.go b/swarm/storage/localstore/localstore_test.go
index c7309d3cd..77340875b 100644
--- a/swarm/storage/localstore/localstore_test.go
+++ b/swarm/storage/localstore/localstore_test.go
@@ -28,9 +28,9 @@ import (
"testing"
"time"
- ch "github.com/ethereum/go-ethereum/swarm/chunk"
- "github.com/ethereum/go-ethereum/swarm/shed"
- "github.com/ethereum/go-ethereum/swarm/storage"
+ ch "github.com/dexon-foundation/dexon/swarm/chunk"
+ "github.com/dexon-foundation/dexon/swarm/shed"
+ "github.com/dexon-foundation/dexon/swarm/storage"
"github.com/syndtr/goleveldb/leveldb"
)
@@ -130,10 +130,10 @@ func TestDB_updateGCSem(t *testing.T) {
// Measurements on MacBook Pro (Retina, 15-inch, Mid 2014) show
// that New function executes around 1s for database with 1M chunks.
//
// # go test -benchmem -run=none github.com/ethereum/go-ethereum/swarm/storage/localstore -bench BenchmarkNew -v -timeout 20m
// goos: darwin
// goarch: amd64
-// pkg: github.com/ethereum/go-ethereum/swarm/storage/localstore
+// pkg: github.com/dexon-foundation/dexon/swarm/storage/localstore
// BenchmarkNew/1000-8 200 11672414 ns/op 9570960 B/op 10008 allocs/op
// BenchmarkNew/10000-8 100 14890609 ns/op 10490118 B/op 7759 allocs/op
// BenchmarkNew/100000-8 20 58334080 ns/op 17763157 B/op 22978 allocs/op
@@ -130,10 +130,10 @@ func TestDB_updateGCSem(t *testing.T) {
// that New function executes around 1s for database with 1M chunks.
//
-// # go test -benchmem -run=none github.com/ethereum/go-ethereum/swarm/storage/localstore -bench BenchmarkNew -v -timeout 20m
+// # go test -benchmem -run=none github.com/dexon-foundation/dexon/swarm/storage/localstore -bench BenchmarkNew -v -timeout 20m
// goos: darwin
// goarch: amd64